ex_dcemri which is a list containing
#' AIF, numeric vector, the averaged enhancement curve recorded in the aorta, the convolution kernel
TUM_1, TUM_2, TUM_3, numeric vectors, three averaged enhancement curves recorded in homogenous regions in the tumor, the observations
times, numeric vector, the observation times
sigma, numeric, the noise level
delta, numeric, equals 0, a time shift assumed to be less than 1 time unit
data(EX_DCEMRI_t0)REMISCAN - Project number IDRCB 2007-A00518-45/P060407/STIC 2006; Research Ethics Board (REB) approved- cohort funding by INCa (1M Euros) and promoted by the AP-HP (Assistance Publique Hôpitaux de Paris). Inclusion target: 100 patients. Start in 2007. Closed since July 2015.